pub const unsafe fn from_utf8_unchecked(v: &[u8]) -> &strThis item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8.
This is an alias to str::from_utf8_unchecked.
See the safe version, from_utf8, for more information.
Safety
The bytes passed in must be valid UTF-8.
Examples
Basic usage: