pub const unsafe fn from_utf8_unchecked_mut(v: &mut [u8]) -> &mut strThis item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8; mutable version.
This is an alias to str::from_utf8_unchecked_mut.
See the immutable version, from_utf8_unchecked() for documentation and safety requirements.
Examples
Basic usage: